==> simpler-6.x-2.0.tar.gz: simpler/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.18 2010/11/06 02:50:22 danprobo Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <?php print $styles; ?>
   <!--[if IE 6]><link rel="stylesheet" href="<?php echo $base_path . $directory; ?>/style.ie6.css" type="text/css" /><![endif]-->
  <?php print $scripts; ?>
 </head>
<body<?php print phptemplate_body_class($left, $right); ?>>
<div id="page">
	<div id="header-wrapper">
	<?php if($secondary_links): ?>
		<div id="sub-menu">
			<?php print theme('links', $secondary_links, array('class' => 'menu')); ?>
		</div> <!-- end sub menu -->
	<?php endif; ?>
	<?php if($search_box): ?>
		<div id="search-wrapper">
			<?php print $search_box; ?>
		</div> <!-- end search wrapper -->
	<?php endif; ?>
	<div id="header">
		<?php if ($logo): ?>
			<div class="logo">
				<a href="<?php print $base_path ?>"><img src="<?php print $logo ?>" alt="<?php print t('Logo') ?>" title="<?php print t('Home') ?>"/></a>
			</div> <!-- end logo -->
		<?php endif; ?>
		<?php if($site_name || $site_slogan): ?>
		<div class="branding">
		<?php if ($site_name): ?>
			<?php if ($is_front) : ?>
			<h1><a href="<?php print $base_path ?>" title="<?php print $site_name ?>"><?php print $site_name ?></a></h1>
			<?php endif; ?>
			<?php if (!$is_front) : ?>
			<h2><a href="<?php print $base_path ?>" title="<?php print $site_name ?>"><?php print $site_name ?></a></h2>
			<?php endif; ?>
		<?php endif; ?>
		<?php if ($site_slogan): ?>
			<span><?php print $site_slogan ?></span>
		<?php endif; ?>
		</div> <!-- end branding -->
		<?php endif; ?>
	</div> <!-- end header -->
	</div> <!-- end header wrapper-->

	<div style="clear:both"></div>

	<div id="menu-wrapper">
	<div id="menu-inner">
	<div id="main-menu">
		<?php if (isset($primary_links)) : ?>
			<?php print theme('links', $primary_links, array('class' => 'menu')) ?>
		<?php endif; ?>
	</div> <!-- end main menu -->
	</div>
	</div> <!-- end menu wrapper -->

	<div style="clear:both"></div>

	<div id="container">
	<div id="container-outer">
	<div id="container-inner">
		<div id="content-wrapper">
			<?php if ($left): ?>
				<div id="sidebar-left" class="sidebar">
					<?php print $left ?>
				</div> <!-- end sidebar left -->
			<?php endif; ?>
			<div id="main-content">
				<?php if ($mission) : ?><div class="mission"><span><?php print $mission; ?></span></div><?php endif; ?>
				<?php if ($teaser) : ?><div class="teaser"><?php print $teaser; ?></span></div><?php endif; ?>
				<?php if (!$is_front) print $breadcrumb; ?>
				<?php if ($show_messages) { print $messages; }; ?>
				<?php if ($tabs) : ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
				<?php if ($title) : ?><h1 class="title"><?php print $title; ?></h1><?php endif; ?>
				<?php print $help; ?>
		      	<?php if ($content) : ?><?php print $content; ?><?php endif; ?>
			</div> <!-- end main content -->
			<?php if ($right): ?>
				<div id="sidebar-right" class="sidebar">
					<?php print $right; ?>
				</div> <!-- end sidebar right -->
			<?php endif; ?> 
		</div> <!-- end content wrapper -->
	</div>
	</div>
	</div> <!-- end container -->

	<div style="clear:both"></div>

	<div id="bottom-wrapper">
		<div id="bottom-inner">
		<?php if($bottom_1 || $bottom_2 || $bottom_3 || $bottom_4) : ?>
    		<div style="clear:both"></div><!-- Do not touch -->
   		<div id="bottom" class="in<?php print (bool) $bottom_1 + (bool) $bottom_2 + (bool) $bottom_3 + (bool) $bottom_4; ?>">
          		<?php if($bottom_1) : ?>
          			<div class="column A">
            			<?php print $bottom_1; ?>
          			</div>
          		<?php endif; ?>
          		<?php if($bottom_2) : ?>
          			<div class="column B">
            			<?php print $bottom_2; ?>
         			</div>
          		<?php endif; ?>
          		<?php if($bottom_3) : ?>
          			<div class="column C">
            			<?php print $bottom_3; ?>
          			</div>
          		<?php endif; ?>
          		<?php if($bottom_4) : ?>
          			<div class="column D">
           				<?php print $bottom_4; ?>
          			</div>
          		<?php endif; ?>
      		<div style="clear:both"></div>
		</div> <!-- end bottom -->
    		<?php endif; ?>
		<div style="clear:both"></div>
	<?php if ($footer): ?>
		<div id="footer-wrapper">
		<div id="footer">
			<?php print $footer; ?>
		</div> <!-- end footer -->
		</div> <!-- end footer wrapper -->
	<?php endif; ?>
		</div> <!-- end bottom inner -->
		<div id="notice">		
		<?php if($footer_message): ?>
			<div id="copyright"><?php print $footer_message; ?></div>
		<?php endif; ?>
		Theme provided by <a href="http://www.danetsoft.com">Danetsoft</a> under GPL license from <a href="http://www.danpros.com">Danang Probo Sayekti</a>
		</div> <!-- end notice -->
    		</div> <!-- end bottom wrapper -->

<div style="clear:both"></div>

</div> <!-- end page -->
<?php print $closure; ?>
</body>
</html>

==> simpler-6.x-2.1.tar.gz: simpler/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.19 2010/11/08 04:37:59 danprobo Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <?php print $styles; ?>
   <!--[if IE 6]><link rel="stylesheet" href="<?php echo $base_path . $directory; ?>/style.ie6.css" type="text/css" /><![endif]-->
  <?php print $scripts; ?>
 </head>
<body<?php print phptemplate_body_class($left, $right); ?>>
<div id="page">
	<div id="header-wrapper">
	<?php if($secondary_links): ?>
		<div id="sub-menu">
			<?php print theme('links', $secondary_links, array('class' => 'menu')); ?>
		</div> <!-- end sub menu -->
	<?php endif; ?>
	<?php if($search_box): ?>
		<div id="search-wrapper">
			<?php print $search_box; ?>
		</div> <!-- end search wrapper -->
	<?php endif; ?>
	<div id="header">
		<?php if ($logo): ?>
			<div class="logo">
				<a href="<?php print $base_path ?>"><img src="<?php print $logo ?>" alt="<?php print t('Logo') ?>" title="<?php print t('Home') ?>"/></a>
			</div> <!-- end logo -->
		<?php endif; ?>
		<?php if($site_name || $site_slogan): ?>
		<div class="branding">
		<?php if ($site_name): ?>
			<?php if ($is_front) : ?>
			<h1><a href="<?php print $base_path ?>" title="<?php print $site_name ?>"><?php print $site_name ?></a></h1>
			<?php endif; ?>
			<?php if (!$is_front) : ?>
			<h2><a href="<?php print $base_path ?>" title="<?php print $site_name ?>"><?php print $site_name ?></a></h2>
			<?php endif; ?>
		<?php endif; ?>
		<?php if ($site_slogan): ?>
			<span><?php print $site_slogan ?></span>
		<?php endif; ?>
		</div> <!-- end branding -->
		<?php endif; ?>
	</div> <!-- end header -->
	</div> <!-- end header wrapper-->

	<div style="clear:both"></div>

	<div id="menu-wrapper">
	<div id="menu-inner">
	<div id="main-menu">
		<?php if (isset($primary_links)) : ?>
			<?php print theme('links', $primary_links, array('class' => 'menu')) ?>
		<?php endif; ?>
	</div> <!-- end main menu -->
	</div>
	</div> <!-- end menu wrapper -->

	<div style="clear:both"></div>

	<div id="container">
	<div id="container-outer">
	<div id="container-inner">
		<div id="content-wrapper">
			<?php if ($left): ?>
				<div id="sidebar-left" class="sidebar">
					<?php print $left ?>
				</div> <!-- end sidebar left -->
			<?php endif; ?>
			<div id="main-content">
				<?php if ($mission) : ?><div class="mission"><span><?php print $mission; ?></span></div><?php endif; ?>
				<?php if ($content_top) : ?><div class="content-top"><?php print $content_top; ?></div><?php endif; ?>
				<?php if (!$is_front) print $breadcrumb; ?>
				<?php if ($show_messages) { print $messages; }; ?>
				<?php if ($tabs) : ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
				<?php if ($title) : ?><h1 class="title"><?php print $title; ?></h1><?php endif; ?>
				<?php print $help; ?>
		      	<?php if ($content) : ?><?php print $content; ?><?php endif; ?>
			</div> <!-- end main content -->
			<?php if ($right): ?>
				<div id="sidebar-right" class="sidebar">
					<?php print $right; ?>
				</div> <!-- end sidebar right -->
			<?php endif; ?> 
		</div> <!-- end content wrapper -->
	</div>
	</div>
	</div> <!-- end container -->

	<div style="clear:both"></div>

	<div id="bottom-wrapper">
		<div id="bottom-inner">
		<?php if($bottom_1 || $bottom_2 || $bottom_3 || $bottom_4) : ?>
    		<div style="clear:both"></div><!-- Do not touch -->
   		<div id="bottom" class="in<?php print (bool) $bottom_1 + (bool) $bottom_2 + (bool) $bottom_3 + (bool) $bottom_4; ?>">
          		<?php if($bottom_1) : ?>
          			<div class="column A">
            			<?php print $bottom_1; ?>
          			</div>
          		<?php endif; ?>
          		<?php if($bottom_2) : ?>
          			<div class="column B">
            			<?php print $bottom_2; ?>
         			</div>
          		<?php endif; ?>
          		<?php if($bottom_3) : ?>
          			<div class="column C">
            			<?php print $bottom_3; ?>
          			</div>
          		<?php endif; ?>
          		<?php if($bottom_4) : ?>
          			<div class="column D">
           				<?php print $bottom_4; ?>
          			</div>
          		<?php endif; ?>
      		<div style="clear:both"></div>
		</div> <!-- end bottom -->
    		<?php endif; ?>
		<div style="clear:both"></div>
	<?php if ($footer): ?>
		<div id="footer-wrapper">
		<div id="footer">
			<?php print $footer; ?>
		</div> <!-- end footer -->
		</div> <!-- end footer wrapper -->
	<?php endif; ?>
		</div> <!-- end bottom inner -->
		<div id="notice">		
		<?php if($footer_message): ?>
			<div id="copyright"><?php print $footer_message; ?></div>
		<?php endif; ?>
		Theme provided by <a href="http://www.danetsoft.com">Danetsoft</a> under GPL license from <a href="http://www.danpros.com">Danang Probo Sayekti</a>
		</div> <!-- end notice -->
    		</div> <!-- end bottom wrapper -->

<div style="clear:both"></div>

</div> <!-- end page -->
<?php print $closure; ?>
</body>
</html>
